@@ -1,6 +1,6 @@
 package POE::Component::DirWatch;
 
-our $VERSION = "0.300000";
+our $VERSION = "0.300001";
 
 use POE;
 use Moose;
@@ -78,6 +78,8 @@ sub BUILD {
         _start   => '_start',
         _pause   => '_pause',
         _resume  => '_resume',
+        _child   => '_child',
+        _stop    => '_stop',
         shutdown => '_shutdown',
         poll     => '_poll',
         ($self->has_dir_callback  ? (dir_callback  => '_dir_callback')  : () ),
@@ -120,6 +122,10 @@ sub _resume {
   $self->next_poll( $kernel->alarm_set(poll => $when) );
 }
 
+sub _stop {}
+
+sub _child {}
+
 #--------#---------#---------#---------#---------#---------#---------#---------
 
 sub pause {
